#!/usr/bin/env python3

import pytest
import pandas as pd
from io import StringIO
import os
import pool_and_psuedoreplicate

test_output_path = os.path.dirname(os.path.abspath(__file__)) + \
                '/../output/design/'

DESIGN_STRING = """sample_id\ttag_align\txcor\treplicate
A_1\tA_1.bedse.gz\tA_1.cc.qc\t1
A_2\tA_2.bedse.gz\tA_2.cc.qc\t2
"""


@pytest.fixture
def design_experiment():
    design_file = StringIO(DESIGN_STRING)
    design_df = pd.read_csv(design_file, sep="\t")
    return design_df


@pytest.fixture
def design_experiment_2(design_experiment):
    # Drop Replicate A_2
    design_df = design_experiment.drop(design_experiment.index[1])
    return design_df


@pytest.mark.unit
def test_check_replicates(design_experiment):
    no_reps = pool_and_psuedoreplicate.check_replicates(design_experiment)
    assert no_reps == 2


@pytest.mark.unit
def test_check_replicates_single(design_experiment_2):
    no_reps = pool_and_psuedoreplicate.check_replicates(design_experiment_2)
    assert no_reps == 1


@pytest.mark.integration
def test_pool_and_psuedoreplicate_single_end():
    design_file = os.path.join(test_output_path, 'ENCSR265ZXX_ppr.tsv')
    assert os.path.exists(design_file)
    design_df = pd.read_csv(design_file, sep="\t")
    assert design_df.shape[0] == 6


@pytest.mark.integration
def test_experiment_design_paired_end():
    # Do the same thing for paired end data
    pass
